#
# spec file for package idutils
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           idutils
Version:        4.6
Release:        5.23
Summary:        Language-Independent Identifier Database Tool
License:        GPL-2.0+
Group:          Productivity/Text/Utilities
Url:            http://www.gnu.org/software/idutils/
Source0:        ftp://ftp.gnu.org/pub/gnu/idutils/idutils-%{version}.tar.xz
Source1:        ftp://ftp.gnu.org/pub/gnu/idutils/idutils-%{version}.tar.xz.sig
Source2:        %{name}.keyring
BuildRequires:  emacs-nox
BuildRequires:  xz
Requires(preun): %{install_info_prereq}
Requires(post): %{install_info_prereq}
Recommends:     %{name}-lang
Provides:       id-utils
Obsoletes:      id-utils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Mkid is a simple, fast, high-capacity, and language-independent
identifier database tool.  Actually, the term identifier is too
limiting--mkid stores tokens, be they program identifiers of any form,
literal numbers, or ordinary words.  Database queries can be issued
from the command line or from within Emacs, serving as an augmented
tags facility.

%lang_package

%prep
%setup -q

%build
%configure
# fix gets compile error https://lists.gnu.org/archive/html/grub-devel/2012-07/msg00051.html
sed -i -e '/gets is a security/d' lib/stdio.in.h
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
install -d %{buildroot}%{_localstatedir}/lib/idutils
mv %{buildroot}%{_datadir}/id-lang.map %{buildroot}%{_localstatedir}/lib/idutils
ln -s ../..%{_localstatedir}/lib/idutils/id-lang.map %{buildroot}%{_datadir}/id-lang.map
# Conflict with libuser
rm -f %{buildroot}%{_mandir}/man1/lid.1
%find_lang %{name}

%post
if test -f %{_infodir}/id-utils.info.gz; then
  mv %{_infodir}/id-utils.info.gz %{_infodir}/id-utils.info.gz.rpmdelete
  %install_info_delete --info-dir=%{_infodir} %{_infodir}/id-utils.info.gz
  mv %{_infodir}/id-utils.info.gz.rpmdelete %{_infodir}/id-utils.info.gz
fi
%install_info --info-dir=%{_infodir} %{_infodir}/idutils.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/idutils.info.gz

%files
%defattr(-,root,root)
%doc ABOUT-NLS AUTHORS COPYING NEWS README THANKS TODO
%config %{_localstatedir}/lib/idutils/id-lang.map
%dir %{_localstatedir}/lib/idutils
%{_datadir}/id-lang.map
%{_datadir}/emacs/site-lisp/idutils.el
%{_datadir}/emacs/site-lisp/idutils.elc
%{_bindir}/*
%{_mandir}/man1/*
%{_infodir}/idutils.info*

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Thu Apr  2 2015 mpluskal@suse.com
- Add gpg signature
- Update dependencies
* Sun Mar  1 2015 p.drouand@gmail.com
- Fix lid manpage conflict for real
* Thu Feb 19 2015 p.drouand@gmail.com
- Do not provide lid manpage as it conflicts with lid manpages
  provided by libuser; temporal solution
* Wed Jan 21 2015 p.drouand@gmail.com
- Update to version 4.6
  * lid -L no longer mishandles open-ended ranges like "..2" and "2.."
  * lid's -d, -o and -x options now work properly
- Remove obsolete AUTHORS section
- Split out translation files into idutils-lang
* Tue Oct 14 2014 jengelh@inai.de
- Enable parallel build and remove ancient specfile tags and sections
* Fri Nov 10 2006 schwab@suse.de
- Try harder.
* Thu Oct 19 2006 schwab@suse.de
- Work around rpm bug.
* Thu Aug 10 2006 schwab@suse.de
- Update to idutils 4.2.
  * Bug fix release.
- Rename to idutils.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 schwab@suse.de
- Update to id-utils 4.0.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Jun 20 2003 ro@suse.de
- fix build with current gettext
* Tue May 13 2003 schwab@suse.de
- Add %%defattr.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Mon Nov 18 2002 ro@suse.de
- set AM_GNU_GETTEXT_VERSION to 0.10.40
- dont clobber po/Makefile
* Sat Mar 30 2002 schwab@suse.de
- Update to id-utils 3.2d.
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Nov  8 2001 schwab@suse.de
- Add libjpeg libpng libtiff libungif to neededforbuild.
* Wed Nov  7 2001 schwab@suse.de
- Fix typo in locate_id_file_name.
* Mon Sep  3 2001 schwab@suse.de
- Fix problem with rehashing.
- Fix crashes due to missing files.
- Use fgets instead of gets.
* Wed Jun  6 2001 schwab@suse.de
- Fix for new configure tools.
* Tue Mar 13 2001 ro@suse.de
- added emacs-x11 to neededforbuild
* Thu Mar  8 2001 schwab@suse.de
- Add xshared to neededforbuild.
* Fri Dec  8 2000 schwab@suse.de
- Use regex from libc.
- Fix configure script.
* Fri Nov 17 2000 kukuk@suse.de
- fix neededforbuild: ge_exec -> emacs
* Tue Oct 24 2000 schwab@suse.de
- Renamed from id_utils
* Thu Jan 20 2000 ke@suse.de
- Apply patch from ak@suse.de: fix segfault when given no arguments
  (#1736).
- /usr/info -> usr/share/info.
- configure -> %%build.
- add group tag.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Mar 17 1999 ro@suse.de
- changed diff file
* Mon Jul 27 1998 bs@suse.de
- added export LC_CTYPE=ISO-8859-1 to build section - emacs needs it.
* Fri Jul 17 1998 ke@suse.de
- Apply patch from Greg McGary to recognize C++ files.
- Improve $RPM_BUILD_ROOT.
* Fri Jul 10 1998 bs@suse.de
- added xaw3d to neededforbuild (ge_exec needs it)
* Thu Oct  9 1997 Karl Eichwalder  <ke@suse.de>
  * .spec: add $RPM_BUILD_ROOT.
* Mon Sep 22 1997 Karl Eichwalder  <ke@suse.de>
  * .spec (preamble): #neededforbuild ge_exec.
  * .spec (%%install): Do Check, create link.
  * .spec (%%post, %%preun): Remove both.
  * .spec (%%files): Add /usr/share/id-lang.map.
* Wed Sep 10 1997 Karl Eichwalder  <ke@suse.de>
  * Use spec file.
* Sat Aug 16 1997 Karl Eichwalder  <ke@suse.de>
  * initial package: version 3.2
